@@ -25,6 +25,7 @@ module BasicPrelude
   , product
     -- ** Text for Read and Show operations
   , show
+  , fromShow
   , read
   , readIO
     -- ** FilePath for file operations
@@ -40,10 +41,12 @@ module BasicPrelude
   , Text.unwords
   , textToString
   , ltextToString
+  , fpToText
+  , fpFromText
+  , fpToString
   , encodeUtf8
   , decodeUtf8
     -- ** Text operations (IO)
-  , Text.putStr
   , Text.getLine
   , LText.getContents
   , LText.interact
@@ -144,6 +147,12 @@ product = foldl' (*) 1
 show :: Show a => a -> Text
 show = Text.pack . Prelude.show
 
+-- | Convert a value to readable IsString
+--
+-- Since 0.3.12
+fromShow :: (Show a, IsString b) => a -> b
+fromShow = fromString . Prelude.show
+
 -- | Parse Text to a value
 read :: Read a => Text -> a
 read = Prelude.read . Text.unpack
@@ -175,6 +184,23 @@ textToString = Text.unpack
 ltextToString :: LText -> Prelude.String
 ltextToString = LText.unpack
 
+-- | This function assumes file paths are encoded in UTF8. If it
+-- cannot decode the 'FilePath', the result is just an approximation.
+--
+-- Since 0.3.13
+fpToText :: FilePath -> Text
+fpToText = either id id . FilePath.toText
+
+-- |
+-- Since 0.3.13
+fpFromText :: Text -> FilePath
+fpFromText = FilePath.fromText
+
+-- |
+-- Since 0.3.13
+fpToString :: FilePath -> Prelude.String
+fpToString = FilePath.encodeString
+
 -- | Note that this is /not/ the standard @Data.Text.Encoding.decodeUtf8@. That
 -- function will throw impure exceptions on any decoding errors. This function
 -- instead uses @decodeLenient@.
