@@ -20,7 +20,9 @@ module CorePrelude
     , Prelude.flip
     , Prelude.const
     , Prelude.error
+    , putStr
     , putStrLn
+    , print
     , getArgs
     , Prelude.odd
     , Prelude.even
@@ -137,11 +139,20 @@ module CorePrelude
     , Control.Exception.IOException
     , Control.Exception.Lifted.throwIO
     , Control.Exception.Lifted.try
+    , Control.Exception.Lifted.tryJust
     , Control.Exception.Lifted.catch
+    , Control.Exception.Lifted.catchJust
     , Control.Exception.Lifted.handle
+    , Control.Exception.Lifted.handleJust
     , Control.Exception.Lifted.bracket
+    , Control.Exception.Lifted.bracket_
+    , Control.Exception.Lifted.bracketOnError
     , Control.Exception.Lifted.onException
     , Control.Exception.Lifted.finally
+    , Control.Exception.Lifted.mask
+    , Control.Exception.Lifted.mask_
+    , Control.Exception.Lifted.uninterruptibleMask
+    , Control.Exception.Lifted.uninterruptibleMask_
     , module System.IO.Error
       -- ** Files
     , F.FilePath
@@ -156,8 +167,6 @@ module CorePrelude
       -- ** Hashing
     , hash
     , hashWithSalt
-      -- ** Print
-    , Prelude.print
       -- ** Command line args
     , readArgs
     ) where
@@ -243,8 +252,14 @@ equating = Data.Function.on (Prelude.==)
 getArgs :: MonadIO m => m [Text]
 getArgs = liftIO (Data.List.map Data.Text.pack <$> System.Environment.getArgs)
 
+putStr :: MonadIO m => Text -> m ()
+putStr = liftIO . Data.Text.IO.putStr
+
 putStrLn :: MonadIO m => Text -> m ()
 putStrLn = liftIO . Data.Text.IO.putStrLn
 
+print :: (MonadIO m, Prelude.Show a) => a -> m ()
+print = liftIO . Prelude.print
+
 readArgs :: (MonadIO m, ReadArgs.ArgumentTuple a) => m a
 readArgs = liftIO ReadArgs.readArgs
